@@ -3,30 +3,34 @@ import os
 import sys
 
 __package__ = "meld"
-__version__ = "3.18.3"
+__version__ = "3.19.0"
 
 # START; these paths are clobbered on install by meld.build_helpers
 DATADIR = os.path.join(sys.prefix, "share", "meld")
 LOCALEDIR = os.path.join(sys.prefix, "share", "locale")
 # END
-
-# Flag enabling some workarounds if data dir isn't installed in standard prefix
-DATADIR_IS_UNINSTALLED = False
+UNINSTALLED = False
+UNINSTALLED_SCHEMA = False
 PYTHON_REQUIREMENT_TUPLE = (3, 3)
 
+
 # Installed from main script
-_ = lambda x: x
-ngettext = lambda x, *args: x
+def no_translation(gettext_string, *args):
+    return gettext_string
+
+
+_ = no_translation
+ngettext = no_translation
 
 
 def frozen():
-    global DATADIR, LOCALEDIR, DATADIR_IS_UNINSTALLED
+    global DATADIR, LOCALEDIR, UNINSTALLED_SCHEMA
 
     melddir = os.path.dirname(sys.executable)
 
     DATADIR = os.path.join(melddir, "share", "meld")
     LOCALEDIR = os.path.join(melddir, "share", "mo")
-    DATADIR_IS_UNINSTALLED = True
+    UNINSTALLED_SCHEMA = True
 
     # This first bit should be unnecessary, but some things (GTK icon theme
     # location, GSettings schema location) don't fall back correctly.
@@ -36,16 +40,15 @@ def frozen():
 
 
 def uninstalled():
-    global DATADIR, LOCALEDIR, DATADIR_IS_UNINSTALLED
+    global DATADIR, LOCALEDIR, UNINSTALLED, UNINSTALLED_SCHEMA
     melddir = os.path.abspath(os.path.join(
         os.path.dirname(os.path.realpath(__file__)), ".."))
 
     DATADIR = os.path.join(melddir, "data")
     LOCALEDIR = os.path.join(melddir, "build", "mo")
-    DATADIR_IS_UNINSTALLED = True
+    UNINSTALLED = True
+    UNINSTALLED_SCHEMA = True
 
-    # This first bit should be unnecessary, but some things (GTK icon theme
-    # location, GSettings schema location) don't fall back correctly.
-    data_dir = os.environ.get('XDG_DATA_DIRS', "/usr/local/share/:/usr/share/")
-    data_dir = ":".join((melddir, data_dir))
-    os.environ['XDG_DATA_DIRS'] = data_dir
+
+def ui_file(filename):
+    return os.path.join(DATADIR, "ui", filename)
